@@ -1,22 +1,19 @@
 """
 Tests that the code can handle RC/FC evaluators that have both async and sync methods.
 """
-from unittest import mock
 
 import inject
 import pytest  # type:ignore[import]
 from maus.edifact import EdifactFormat, EdifactFormatVersion
 
-from ahbicht.content_evaluation.evaluationdatatypes import EvaluatableData
+from ahbicht.content_evaluation.evaluationdatatypes import EvaluatableData, EvaluatableDataProvider, EvaluationContext
 from ahbicht.content_evaluation.fc_evaluators import FcEvaluator
-from ahbicht.content_evaluation.rc_evaluators import DictBasedRcEvaluator, RcEvaluator
+from ahbicht.content_evaluation.rc_evaluators import RcEvaluator
 from ahbicht.expressions.ahb_expression_evaluation import evaluate_ahb_expression_tree
 from ahbicht.expressions.condition_nodes import ConditionFulfilledValue, EvaluatedFormatConstraint
 from ahbicht.expressions.expression_resolver import parse_expression_including_unresolved_subexpressions
 from ahbicht.expressions.hints_provider import DictBasedHintsProvider, HintsProvider
 
-pytestmark = pytest.mark.asyncio
-
 
 class MixedSyncAsyncRcEvaluator(RcEvaluator):
     """An RC evaluator that has both sync and async methods"""
@@ -27,10 +24,16 @@ class MixedSyncAsyncRcEvaluator(RcEvaluator):
     def _get_default_context(self):
         return None  # type:ignore[return-value]
 
-    def evaluate_1(self, _):
+    def evaluate_1(self, evaluatable_data, context):
+        assert isinstance(evaluatable_data, EvaluatableData)
+        if context is not None:
+            assert isinstance(context, EvaluationContext)
         return ConditionFulfilledValue.FULFILLED
 
-    async def evaluate_2(self, _):
+    async def evaluate_2(self, evaluatable_data, context):
+        assert isinstance(evaluatable_data, EvaluatableData)
+        if context is not None:
+            assert isinstance(context, EvaluationContext)
         return ConditionFulfilledValue.UNFULFILLED
 
 
@@ -60,11 +63,16 @@ class TestMixedSyncAsyncEvaluation:
         self, expression: str, expected_rc_fulfilled: bool, expected_fc_fulfilled: bool
     ):
         fc_evaluator = MixedSyncAsyncFcEvaluator()
-        rc_evaluator = MixedSyncAsyncRcEvaluator(EvaluatableData(edifact_seed={}))
+
+        def get_evaluatable_data():
+            return EvaluatableData(edifact_seed={})
+
+        rc_evaluator = MixedSyncAsyncRcEvaluator()
         inject.clear_and_configure(
             lambda binder: binder.bind(RcEvaluator, rc_evaluator)  # type:ignore[arg-type]
             .bind(FcEvaluator, fc_evaluator)
             .bind(HintsProvider, DictBasedHintsProvider({}))
+            .bind_to_provider(EvaluatableDataProvider, get_evaluatable_data)
         )
         evaluation_input = "something has to be here but it's not important what"
         tree = await parse_expression_including_unresolved_subexpressions(expression)
